@@ -1,7 +1,7 @@
 /* libsrconf.h
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -44,23 +44,17 @@
 #define DEFAULT_BRLMON_PORT			7000
 #define DEFAULT_REMOTE_PORT			7096
 /*____________________________< BRAILLE_DEFAULTS>___________________________*/
-#define MIN_SERIAL_PORT_NO			1
-#define MAX_SERIAL_PORT_NO			4
-
-#define MIN_TTY_CONSOL_NO			1
-#define MAX_TTY_CONSOL_NO			10
-
-#define MIN_BRAILLE_PORT 			1
-#define MAX_BRAILLE_PORT 			10
+#define MIN_SERIAL_PORT_NO			-1
+#define MAX_SERIAL_PORT_NO			3
 
 #define DEFAULT_BRAILLE_ATTRIBUTES		8
 #define DEFAULT_BRAILLE_STYLE 			"8"
 #define DEFAULT_BRAILLE_CURSOR_STYLE		"underline"
 #define DEFAULT_BRAILLE_TRANSLATION 		"de"
-#define DEFAULT_BRAILLE_DEVICE 			"VARIO20"
+#define DEFAULT_BRAILLE_DEVICE 			"BRLTTY"
 #define DEFAULT_BRAILLE_DEVICE_INDEX 		0
 #define DEFAULT_BRAILLE_DEVICE_COUNT		0
-#define DEFAULT_BRAILLE_PORT_NO 		1
+#define DEFAULT_BRAILLE_PORT_NO 		-1
 #define DEFAULT_BRAILLE_FILL_CHAR 		"##"
 #define DEFAULT_BRAILLE_STATUS_CELL 		"CursorPos"
 #define DEFAULT_BRAILLE_OPTICAL_SENSOR 		0
@@ -97,20 +91,20 @@
 
 /*____________________________< SRCORE_DEFAULTS>____________________________*/
 /*____________________________< SPEECH_DEFAULTS>____________________________*/
-#define SPEECH_RATE_STEP			5
+#define SPEECH_RATE_STEP			15
 #define SPEECH_VOLUME_STEP			5
-#define SPEECH_PITCH_STEP			5
+#define SPEECH_PITCH_STEP			25
 
-#define MAX_SPEECH_RATE				100
-#define MIN_SPEECH_RATE				0
-#define MAX_SPEECH_PITCH 			100
-#define MIN_SPEECH_PITCH 			0
+#define MAX_SPEECH_RATE				400
+#define MIN_SPEECH_RATE				30
+#define MAX_SPEECH_PITCH 			500
+#define MIN_SPEECH_PITCH 			10
 #define MAX_SPEECH_VOLUME 			100
 #define MIN_SPEECH_VOLUME 			0
 
 #define DEFAULT_SPEECH_PREEMPT 			TRUE
-#define DEFAULT_SPEECH_RATE 			25
-#define DEFAULT_SPEECH_PITCH 			12
+#define DEFAULT_SPEECH_RATE 			150
+#define DEFAULT_SPEECH_PITCH 			100
 #define DEFAULT_SPEECH_VOLUME 			100
 #define DEFAULT_SPEECH_COUNT_TYPE		"NONE"
 #define DEFAULT_SPEECH_VOICE_COUNT		0
@@ -120,8 +114,8 @@
 #define DEFAULT_SPEECH_MODIFIERS		"NONE"
 #define DEFAULT_SPEECH_CURSORS			"NONE"
 #define DEFAULT_SPEECH_SPACES			"ALL"
-#define DEFAULT_SPEECH_ENGINE_VOICE		"V0 Adult Male 1 - IBM Viavoice GNOME Speech Driver"
-#define DEFAULT_SPEECH_ENGINE_DRIVER 		"IBM Viavoice GNOME Speech Driver"
+#define DEFAULT_SPEECH_ENGINE_VOICE		"V0 kevin - FreeTTS Gnome Speech Driver"
+#define DEFAULT_SPEECH_ENGINE_DRIVER 		"FreeTTS_Gnome_Speech_Driver"
 #define DEFAULT_SPEECH_DICTIONARY_ACTIVE	"NO"
 #define DEFAULT_SPEECH_DICTIONARY_ENTRY 	"USA<>United States Of America" 
 /*____________________________< /SPEECH_DEFAULTS>___________________________*/
